pub struct GoogleCloudDataplexV1DataDiscoveryResultScanStatistics {
pub data_processed_bytes: Option<i64>,
pub files_excluded: Option<i32>,
pub filesets_created: Option<i32>,
pub filesets_deleted: Option<i32>,
pub filesets_updated: Option<i32>,
pub scanned_file_count: Option<i32>,
pub tables_created: Option<i32>,
pub tables_deleted: Option<i32>,
pub tables_updated: Option<i32>,
}Expand description
Describes result statistics of a data scan discovery job.
This type is not used in any activity, and only used as part of another schema.
Fields
data_processed_bytes: Option<i64>The data processed in bytes.
files_excluded: Option<i32>The number of files excluded.
filesets_created: Option<i32>The number of filesets created.
filesets_deleted: Option<i32>The number of filesets deleted.
filesets_updated: Option<i32>The number of filesets updated.
scanned_file_count: Option<i32>The number of files scanned.
tables_created: Option<i32>The number of tables created.
tables_deleted: Option<i32>The number of tables deleted.
tables_updated: Option<i32>The number of tables updated.