pub struct GoogleCloudDataplexV1DataDiscoverySpecStorageConfigCsvOptions {
pub delimiter: Option<String>,
pub encoding: Option<String>,
pub header_rows: Option<i32>,
pub quote: Option<String>,
pub type_inference_disabled: Option<bool>,
}Expand description
Describes CSV and similar semi-structured data formats.
This type is not used in any activity, and only used as part of another schema.
Fields
delimiter: Option<String>Optional. The delimiter that is used to separate values. The default is , (comma).
encoding: Option<String>Optional. The character encoding of the data. The default is UTF-8.
header_rows: Option<i32>Optional. The number of rows to interpret as header rows that should be skipped when reading data rows.
quote: Option<String>Optional. The character used to quote column values. Accepts “ (double quotation mark) or ’ (single quotation mark). If unspecified, defaults to “ (double quotation mark).
type_inference_disabled: Option<bool>Optional. Whether to disable the inference of data types for CSV data. If true, all columns are registered as strings.