pub struct GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions {
pub encoding: Option<String>,
pub type_inference_disabled: Option<bool>,
}Expand description
Describes JSON data format.
This type is not used in any activity, and only used as part of another schema.
Fields
encoding: Option<String>Optional. The character encoding of the data. The default is UTF-8.
type_inference_disabled: Option<bool>Optional. Whether to disable the inference of data types for JSON data. If true, all columns are registered as their primitive types (strings, number, or boolean).