pub struct GoogleCloudDataplexV1DataDocumentationResultField {
pub description: Option<String>,
pub fields: Option<Vec<GoogleCloudDataplexV1DataDocumentationResultField>>,
pub name: Option<String>,
}Expand description
Column of a table with generated metadata and nested fields.
This type is not used in any activity, and only used as part of another schema.
Fields
description: Option<String>Output only. Generated description for columns and fields.
fields: Option<Vec<GoogleCloudDataplexV1DataDocumentationResultField>>Output only. Nested fields.
name: Option<String>Output only. The name of the column.