pub struct GoogleCloudDataplexV1DataDocumentationResultSchema {
pub fields: Option<Vec<GoogleCloudDataplexV1DataDocumentationResultField>>,
}Expand description
Schema of the table with generated metadata of columns.
This type is not used in any activity, and only used as part of another schema.
Fields
fields: Option<Vec<GoogleCloudDataplexV1DataDocumentationResultField>>Output only. The list of columns.