pub struct GoogleCloudDataplexV1DataDocumentationResultTableResult {
pub name: Option<String>,
pub overview: Option<String>,
pub queries: Option<Vec<GoogleCloudDataplexV1DataDocumentationResultQuery>>,
pub schema: Option<GoogleCloudDataplexV1DataDocumentationResultSchema>,
}Expand description
Generated metadata about the table.
This type is not used in any activity, and only used as part of another schema.
Fields
name: Option<String>Output only. The service-qualified full resource name of the cloud resource. Ex: //bigquery.googleapis.com/projects/PROJECT_ID/datasets/DATASET_ID/tables/TABLE_ID
overview: Option<String>Output only. Generated description of the table.
queries: Option<Vec<GoogleCloudDataplexV1DataDocumentationResultQuery>>Output only. Sample SQL queries for the table.
schema: Option<GoogleCloudDataplexV1DataDocumentationResultSchema>Output only. Schema of the table with generated metadata of the columns in the schema.