GoogleCloudDataplexV1DataProductAccessGroup

Struct GoogleCloudDataplexV1DataProductAccessGroup 

pub struct GoogleCloudDataplexV1DataProductAccessGroup {
    pub description: Option<String>,
    pub display_name: Option<String>,
    pub id: Option<String>,
    pub principal: Option<GoogleCloudDataplexV1DataProductPrincipal>,
}
Custom user defined access groups at the Data Product level. These are used for granting different levels of access (IAM roles) on the individual Data Product’s Data Assets.

This type is not used in any activity, and only used as part of another schema.

Fields

description: Option<String>

Optional. Description of the access group.

display_name: Option<String>

Required. User friendly display name of the access group. Eg. “Analyst”, “Developer”, etc.

id: Option<String>

Required. Unique identifier of the access group within the Data Product. User defined. Eg. “analyst”, “developer”, etc.

principal: Option<GoogleCloudDataplexV1DataProductPrincipal>

Required. The principal entity associated with this access group.