pub struct GoogleCloudDataplexV1DataProductPrincipal {
pub google_group: Option<String>,
}Expand description
Represents the principal entity associated with an access group, as per https://cloud.google.com/iam/docs/principals-overview.
This type is not used in any activity, and only used as part of another schema.
Fields
google_group: Option<String>Email of the Google Group, as per https://cloud.google.com/iam/docs/principals-overview#google-group.