pub struct GoogleCloudDataplexV1DataQualityResultAnomalyDetectionGeneratedAssets {
pub data_intermediate_table: Option<String>,
pub freshness_intermediate_table: Option<String>,
pub result_table: Option<String>,
pub volume_intermediate_table: Option<String>,
}Expand description
The assets generated by Anomaly Detection Data Scan.
This type is not used in any activity, and only used as part of another schema.
Fields
data_intermediate_table: Option<String>Output only. The intermediate table for data anomaly detection. Format: PROJECT_ID.DATASET_ID.TABLE_ID
freshness_intermediate_table: Option<String>Output only. The intermediate table for freshness anomaly detection. Format: PROJECT_ID.DATASET_ID.TABLE_ID
result_table: Option<String>Output only. The result table for anomaly detection. Format: PROJECT_ID.DATASET_ID.TABLE_ID If the result table is set at AnomalyDetectionAssets, the result table here would be the same as the one set in the AnomalyDetectionAssets.result_table.
volume_intermediate_table: Option<String>Output only. The intermediate table for volume anomaly detection. Format: PROJECT_ID.DATASET_ID.TABLE_ID