GoogleCloudDataplexV1DataScan

Struct GoogleCloudDataplexV1DataScan 

pub struct GoogleCloudDataplexV1DataScan {
Show 20 fields pub create_time: Option<DateTime<Utc>>, pub data: Option<GoogleCloudDataplexV1DataSource>, pub data_discovery_result: Option<GoogleCloudDataplexV1DataDiscoveryResult>, pub data_discovery_spec: Option<GoogleCloudDataplexV1DataDiscoverySpec>, pub data_documentation_result: Option<GoogleCloudDataplexV1DataDocumentationResult>, pub data_documentation_spec: Option<GoogleCloudDataplexV1DataDocumentationSpec>, pub data_profile_result: Option<GoogleCloudDataplexV1DataProfileResult>, pub data_profile_spec: Option<GoogleCloudDataplexV1DataProfileSpec>, pub data_quality_result: Option<GoogleCloudDataplexV1DataQualityResult>, pub data_quality_spec: Option<GoogleCloudDataplexV1DataQualitySpec>, pub description: Option<String>, pub display_name: Option<String>, pub execution_spec: Option<GoogleCloudDataplexV1DataScanExecutionSpec>, pub execution_status: Option<GoogleCloudDataplexV1DataScanExecutionStatus>, pub labels: Option<HashMap<String, String>>, pub name: Option<String>, pub state: Option<String>, pub type_: Option<String>, pub uid: Option<String>, pub update_time: Option<DateTime<Utc>>,
}
Represents a user-visible job which provides the insights for the related data source.For example: Data quality: generates queries based on the rules and runs against the data to get data quality check results. For more information, see Auto data quality overview (https://cloud.google.com/dataplex/docs/auto-data-quality-overview). Data profile: analyzes the data in tables and generates insights about the structure, content and relationships (such as null percent, cardinality, min/max/mean, etc). For more information, see About data profiling (https://cloud.google.com/dataplex/docs/data-profiling-overview). Data discovery: scans data in Cloud Storage buckets to extract and then catalog metadata. For more information, see Discover and catalog Cloud Storage data (https://cloud.google.com/bigquery/docs/automatic-discovery). Data documentation: analyzes the table details and generates insights including descriptions and sample SQL queries for the table. For more information, see Generate data insights in BigQuery (https://cloud.google.com/bigquery/docs/data-insights).

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

create_time: Option<DateTime<Utc>>

Output only. The time when the scan was created.

data: Option<GoogleCloudDataplexV1DataSource>

Required. The data source for DataScan.

data_discovery_result: Option<GoogleCloudDataplexV1DataDiscoveryResult>

Output only. The result of a data discovery scan.

data_discovery_spec: Option<GoogleCloudDataplexV1DataDiscoverySpec>

Settings for a data discovery scan.

data_documentation_result: Option<GoogleCloudDataplexV1DataDocumentationResult>

Output only. The result of a data documentation scan.

data_documentation_spec: Option<GoogleCloudDataplexV1DataDocumentationSpec>

Settings for a data documentation scan.

data_profile_result: Option<GoogleCloudDataplexV1DataProfileResult>

Output only. The result of a data profile scan.

data_profile_spec: Option<GoogleCloudDataplexV1DataProfileSpec>

Settings for a data profile scan.

data_quality_result: Option<GoogleCloudDataplexV1DataQualityResult>

Output only. The result of a data quality scan.

data_quality_spec: Option<GoogleCloudDataplexV1DataQualitySpec>

Settings for a data quality scan.

description: Option<String>

Optional. Description of the scan. Must be between 1-1024 characters.

display_name: Option<String>

Optional. User friendly display name. Must be between 1-256 characters.

execution_spec: Option<GoogleCloudDataplexV1DataScanExecutionSpec>

Optional. DataScan execution settings.If not specified, the fields in it will use their default values.

execution_status: Option<GoogleCloudDataplexV1DataScanExecutionStatus>

Output only. Status of the data scan execution.

labels: Option<HashMap<String, String>>

Optional. User-defined labels for the scan.

name: Option<String>

Output only. Identifier. The relative resource name of the scan, of the form: projects/{project}/locations/{location_id}/dataScans/{datascan_id}, where project refers to a project_id or project_number and location_id refers to a Google Cloud region.

state: Option<String>

Output only. Current state of the DataScan.

type_: Option<String>

Output only. The type of DataScan.

uid: Option<String>

Output only. System generated globally unique ID for the scan. This ID will be different if the scan is deleted and re-created with the same name.

update_time: Option<DateTime<Utc>>

Output only. The time when the scan was last updated.