pub struct GoogleCloudDataplexV1DataScanCatalogPublishingStatus {
pub state: Option<String>,
}Expand description
The status of publishing the data scan result as Dataplex Universal Catalog metadata. Multiple DataScan log events may exist, each with different publishing information depending on the type of publishing triggered.
This type is not used in any activity, and only used as part of another schema.
Fields
state: Option<String>Output only. Execution state for publishing.