GoogleCloudDataplexV1EncryptionConfigFailureDetails

Struct GoogleCloudDataplexV1EncryptionConfigFailureDetails 

pub struct GoogleCloudDataplexV1EncryptionConfigFailureDetails {
    pub error_code: Option<String>,
    pub error_message: Option<String>,
}
Details of the failure if anything related to Cmek db fails.

This type is not used in any activity, and only used as part of another schema.

Fields

error_code: Option<String>

Output only. The error code for the failure.

error_message: Option<String>

Output only. The error message will be shown to the user. Set only if the error code is REQUIRE_USER_ACTION.