pub struct GoogleCloudDataplexV1EntryType {Show 13 fields
pub authorization: Option<GoogleCloudDataplexV1EntryTypeAuthorization>,
pub create_time: Option<DateTime<Utc>>,
pub description: Option<String>,
pub display_name: Option<String>,
pub etag: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub name: Option<String>,
pub platform: Option<String>,
pub required_aspects: Option<Vec<GoogleCloudDataplexV1EntryTypeAspectInfo>>,
pub system: Option<String>,
pub type_aliases: Option<Vec<String>>,
pub uid: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
Entry Type is a template for creating Entries.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations entry types create projects (request)
- locations entry types get projects (response)
- locations entry types patch projects (request)
Fields
Immutable. Authorization defined for this type.
create_time: Option<DateTime<Utc>>Output only. The time when the EntryType was created.
description: Option<String>Optional. Description of the EntryType.
display_name: Option<String>Optional. User friendly display name.
etag: Option<String>Optional. This checksum is computed by the service, and might be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
labels: Option<HashMap<String, String>>Optional. User-defined labels for the EntryType.
name: Option<String>Output only. The relative resource name of the EntryType, of the form: projects/{project_number}/locations/{location_id}/entryTypes/{entry_type_id}.
platform: Option<String>Optional. The platform that Entries of this type belongs to.
required_aspects: Option<Vec<GoogleCloudDataplexV1EntryTypeAspectInfo>>AspectInfo for the entry type.
system: Option<String>Optional. The system that Entries of this type belongs to. Examples include CloudSQL, MariaDB etc
type_aliases: Option<Vec<String>>Optional. Indicates the classes this Entry Type belongs to, for example, TABLE, DATABASE, MODEL.
uid: Option<String>Output only. System generated globally unique ID for the EntryType. This ID will be different if the EntryType is deleted and re-created with the same name.
update_time: Option<DateTime<Utc>>Output only. The time when the EntryType was last updated.