pub struct GoogleCloudDataplexV1EnvironmentInfrastructureSpecComputeResources {
pub disk_size_gb: Option<i32>,
pub max_node_count: Option<i32>,
pub node_count: Option<i32>,
}Expand description
Compute resources associated with the analyze interactive workloads.
This type is not used in any activity, and only used as part of another schema.
Fields
disk_size_gb: Option<i32>Optional. Size in GB of the disk. Default is 100 GB.
max_node_count: Option<i32>Optional. Max configurable nodes. If max_node_count > node_count, then auto-scaling is enabled.
node_count: Option<i32>Optional. Total number of nodes in the sessions created for this environment.