pub struct GoogleCloudDataplexV1MetadataJobExportJobResult {
pub error_message: Option<String>,
pub exported_entries: Option<i64>,
}Expand description
Summary results from a metadata export job. The results are a snapshot of the metadata at the time when the job was created. The exported entries are saved to a Cloud Storage bucket.
This type is not used in any activity, and only used as part of another schema.
Fields
error_message: Option<String>Output only. The error message if the metadata export job failed.
exported_entries: Option<i64>Output only. The number of entries that were exported.