GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope

Struct GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope 

pub struct GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope {
    pub aspect_types: Option<Vec<String>>,
    pub entry_groups: Option<Vec<String>>,
    pub entry_types: Option<Vec<String>>,
    pub organization_level: Option<bool>,
    pub projects: Option<Vec<String>>,
}
The scope of the export job.

This type is not used in any activity, and only used as part of another schema.

Fields

aspect_types: Option<Vec<String>>

The aspect types that are in scope for the export job, specified as relative resource names in the format projects/{project_id_or_number}/locations/{location}/aspectTypes/{aspect_type_id}. Only aspects that belong to the specified aspect types are affected by the job.

entry_groups: Option<Vec<String>>

The entry groups whose metadata you want to export, in the format projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}. Only the entries in the specified entry groups are exported.The entry groups must be in the same location and the same VPC Service Controls perimeter as the job.If you set the job scope to be a list of entry groups, then set the organization-level export flag to false and don’t provide a list of projects.

entry_types: Option<Vec<String>>

The entry types that are in scope for the export job, specified as relative resource names in the format projects/{project_id_or_number}/locations/{location}/entryTypes/{entry_type_id}. Only entries that belong to the specified entry types are affected by the job.

organization_level: Option<bool>

Whether the metadata export job is an organization-level export job. If true, the job exports the entries from the same organization and VPC Service Controls perimeter as the job. The project that the job belongs to determines the VPC Service Controls perimeter. If you set the job scope to be at the organization level, then don’t provide a list of projects or entry groups. If false, you must specify a list of projects or a list of entry groups whose entries you want to export.The default is false.

projects: Option<Vec<String>>

The projects whose metadata you want to export, in the format projects/{project_id_or_number}. Only the entries from the specified projects are exported.The projects must be in the same organization and VPC Service Controls perimeter as the job.If you set the job scope to be a list of projects, then set the organization-level export flag to false and don’t provide a list of entry groups.