pub struct GoogleCloudDataplexV1MetadataJobImportJobResult {
pub created_entries: Option<i64>,
pub created_entry_links: Option<i64>,
pub deleted_entries: Option<i64>,
pub deleted_entry_links: Option<i64>,
pub recreated_entries: Option<i64>,
pub unchanged_entries: Option<i64>,
pub unchanged_entry_links: Option<i64>,
pub update_time: Option<DateTime<Utc>>,
pub updated_entries: Option<i64>,
}Expand description
Results from a metadata import job.
This type is not used in any activity, and only used as part of another schema.
Fields
created_entries: Option<i64>Output only. The total number of entries that were created.
created_entry_links: Option<i64>Output only. The total number of entry links that were successfully created.
deleted_entries: Option<i64>Output only. The total number of entries that were deleted.
deleted_entry_links: Option<i64>Output only. The total number of entry links that were successfully deleted.
recreated_entries: Option<i64>Output only. The total number of entries that were recreated.
unchanged_entries: Option<i64>Output only. The total number of entries that were unchanged.
unchanged_entry_links: Option<i64>Output only. The total number of entry links that were left unchanged.
update_time: Option<DateTime<Utc>>Output only. The time when the status was updated.
updated_entries: Option<i64>Output only. The total number of entries that were updated.