pub struct GoogleCloudDataplexV1MetadataJobImportJobSpec {
pub aspect_sync_mode: Option<String>,
pub entry_sync_mode: Option<String>,
pub log_level: Option<String>,
pub scope: Option<GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope>,
pub source_create_time: Option<DateTime<Utc>>,
pub source_storage_uri: Option<String>,
}Expand description
Job specification for a metadata import job.You can run the following kinds of metadata import jobs: Full sync of entries with incremental import of their aspects. Supported for custom entries. Incremental import of aspects only. Supported for aspects that belong to custom entries and system entries. For custom entries, you can modify both optional aspects and required aspects. For system entries, you can modify optional aspects.
This type is not used in any activity, and only used as part of another schema.
Fields
aspect_sync_mode: Option<String>Required. The sync mode for aspects.
entry_sync_mode: Option<String>Required. The sync mode for entries.
log_level: Option<String>Optional. The level of logs to write to Cloud Logging for this job.Debug-level logs provide highly-detailed information for troubleshooting, but their increased verbosity could incur additional costs (https://cloud.google.com/stackdriver/pricing) that might not be merited for all jobs.If unspecified, defaults to INFO.
scope: Option<GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope>Required. A boundary on the scope of impact that the metadata import job can have.
source_create_time: Option<DateTime<Utc>>Optional. The time when the process that created the metadata import files began.
source_storage_uri: Option<String>Optional. The URI of a Cloud Storage bucket or folder (beginning with gs:// and ending with /) that contains the metadata import files for this job.A metadata import file defines the values to set for each of the entries and aspects in a metadata import job. For more information about how to create a metadata import file and the file requirements, see Metadata import file (https://cloud.google.com/dataplex/docs/import-metadata#metadata-import-file).You can provide multiple metadata import files in the same metadata job. The bucket or folder must contain at least one metadata import file, in JSON Lines format (either .json or .jsonl file extension).In FULL entry sync mode, don’t save the metadata import file in a folder named SOURCE_STORAGE_URI/deletions/.Caution: If the metadata import file contains no data, all entries and aspects that belong to the job’s scope are deleted.