GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope

Struct GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope 

pub struct GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope {
    pub aspect_types: Option<Vec<String>>,
    pub entry_groups: Option<Vec<String>>,
    pub entry_link_types: Option<Vec<String>>,
    pub entry_types: Option<Vec<String>>,
    pub glossaries: Option<Vec<String>>,
    pub referenced_entry_scopes: Option<Vec<String>>,
}
A boundary on the scope of impact that the metadata import job can have.

This type is not used in any activity, and only used as part of another schema.

Fields

aspect_types: Option<Vec<String>>

Optional. The aspect types that are in scope for the import job, specified as relative resource names in the format projects/{project_number_or_id}/locations/{location_id}/aspectTypes/{aspect_type_id}. The job modifies only the aspects that belong to these aspect types.This field is required when creating an aspect-only import job.If the metadata import file attempts to modify an aspect whose type isn’t included in this list, the import job is halted before modifying any entries or aspects.The location of an aspect type must either match the location of the job, or the aspect type must be global.

entry_groups: Option<Vec<String>>

Required. The entry groups that are in scope for the import job, specified as relative resource names in the format projects/{project_number_or_id}/locations/{location_id}/entryGroups/{entry_group_id}. Only entries and aspects that belong to the specified entry groups are affected by the job.The entry groups and the job must be in the same location.

entry_link_types: Option<Vec<String>>

Optional. The entry link types that are in scope for the import job, specified as relative resource names in the format projects/{project_number_or_id}/locations/{location_id}/entryLinkTypes/{entry_link_type_id}. The job modifies only the entryLinks that belong to these entry link types.If the metadata import file attempts to create or delete an entry link whose entry link type isn’t included in this list, the import job will skip those entry links.

entry_types: Option<Vec<String>>

Required. The entry types that are in scope for the import job, specified as relative resource names in the format projects/{project_number_or_id}/locations/{location_id}/entryTypes/{entry_type_id}. The job modifies only the entries and aspects that belong to these entry types.If the metadata import file attempts to modify an entry whose type isn’t included in this list, the import job is halted before modifying any entries or aspects.The location of an entry type must either match the location of the job, or the entry type must be global.

glossaries: Option<Vec<String>>

Optional. The glossaries that are in scope for the import job, specified as relative resource names in the format projects/{project_number_or_id}/locations/{location_id}/glossaries/{glossary_id}.While importing Business Glossary entries, the user must provide glossaries. While importing entries, the user does not have to provide glossaries. If the metadata import file attempts to modify Business Glossary entries whose glossary isn’t included in this list, the import job will skip those entries.The location of a glossary must either match the location of the job, or the glossary must be global.

referenced_entry_scopes: Option<Vec<String>>

Optional. Defines the scope of entries that can be referenced in the entry links.Currently, projects are supported as valid scopes. Format: projects/{project_number_or_id}If the metadata import file attempts to create an entry link which references an entry that is not in the scope, the import job will skip that entry link.