pub struct GoogleCloudDataplexV1MetadataJobStatus {
pub completion_percent: Option<i32>,
pub message: Option<String>,
pub state: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
Metadata job status.
This type is not used in any activity, and only used as part of another schema.
Fields
completion_percent: Option<i32>Output only. Progress tracking.
message: Option<String>Output only. Message relating to the progression of a metadata job.
state: Option<String>Output only. State of the metadata job.
update_time: Option<DateTime<Utc>>Output only. The time when the status was updated.