pub struct GoogleCloudDataplexV1RunTaskRequest {
pub args: Option<HashMap<String, String>>,
pub labels: Option<HashMap<String, String>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations lakes tasks run projects (request)
Fields
args: Option<HashMap<String, String>>Optional. Execution spec arguments. If the map is left empty, the task will run with existing execution spec args from task definition. If the map contains an entry with a new key, the same will be added to existing set of args. If the map contains an entry with an existing arg key in task definition, the task will run with new arg value for that entry. Clearing an existing arg will require arg value to be explicitly set to a hyphen “-”. The arg value cannot be empty.
labels: Option<HashMap<String, String>>Optional. User-defined labels for the task. If the map is left empty, the task will run with existing labels from task definition. If the map contains an entry with a new key, the same will be added to existing set of labels. If the map contains an entry with an existing label key in task definition, the task will run with new label value for that entry. Clearing an existing label will require label value to be explicitly set to a hyphen “-”. The label value cannot be empty.