pub struct GoogleCloudDataplexV1StorageFormat {
pub compression_format: Option<String>,
pub csv: Option<GoogleCloudDataplexV1StorageFormatCsvOptions>,
pub format: Option<String>,
pub iceberg: Option<GoogleCloudDataplexV1StorageFormatIcebergOptions>,
pub json: Option<GoogleCloudDataplexV1StorageFormatJsonOptions>,
pub mime_type: Option<String>,
}Expand description
Describes the format of the data within its storage location.
This type is not used in any activity, and only used as part of another schema.
Fields
compression_format: Option<String>Optional. The compression type associated with the stored data. If unspecified, the data is uncompressed.
csv: Option<GoogleCloudDataplexV1StorageFormatCsvOptions>Optional. Additional information about CSV formatted data.
format: Option<String>Output only. The data format associated with the stored data, which represents content type values. The value is inferred from mime type.
iceberg: Option<GoogleCloudDataplexV1StorageFormatIcebergOptions>Optional. Additional information about iceberg tables.
json: Option<GoogleCloudDataplexV1StorageFormatJsonOptions>Optional. Additional information about CSV formatted data.
mime_type: Option<String>Required. The mime type descriptor for the data. Must match the pattern {type}/{subtype}. Supported values: application/x-parquet application/x-avro application/x-orc application/x-tfrecord application/x-parquet+iceberg application/x-avro+iceberg application/x-orc+iceberg application/json application/{subtypes} text/csv text/ image/{image subtype} video/{video subtype} audio/{audio subtype}