pub struct GoogleCloudDataplexV1TaskExecutionSpec {
pub args: Option<HashMap<String, String>>,
pub kms_key: Option<String>,
pub max_job_execution_lifetime: Option<Duration>,
pub project: Option<String>,
pub service_account: Option<String>,
}Expand description
Execution related settings, like retry and service_account.
This type is not used in any activity, and only used as part of another schema.
Fields
args: Option<HashMap<String, String>>Optional. The arguments to pass to the task. The args can use placeholders of the format ${placeholder} as part of key/value string. These will be interpolated before passing the args to the driver. Currently supported placeholders: - ${task_id} - ${job_time} To pass positional args, set the key as TASK_ARGS. The value should be a comma-separated string of all the positional arguments. To use a delimiter other than comma, refer to https://cloud.google.com/sdk/gcloud/reference/topic/escaping. In case of other keys being present in the args, then TASK_ARGS will be passed as the last argument.
kms_key: Option<String>Optional. The Cloud KMS key to use for encryption, of the form: projects/{project_number}/locations/{location_id}/keyRings/{key-ring-name}/cryptoKeys/{key-name}.
max_job_execution_lifetime: Option<Duration>Optional. The maximum duration after which the job execution is expired.
project: Option<String>Optional. The project in which jobs are run. By default, the project containing the Lake is used. If a project is provided, the ExecutionSpec.service_account must belong to this project.
service_account: Option<String>Required. Service account to use to execute a task. If not provided, the default Compute service account for the project is used.