pub struct GoogleCloudDataplexV1TaskInfrastructureSpecContainerImageRuntime {
pub image: Option<String>,
pub java_jars: Option<Vec<String>>,
pub properties: Option<HashMap<String, String>>,
pub python_packages: Option<Vec<String>>,
}Expand description
Container Image Runtime Configuration used with Batch execution.
This type is not used in any activity, and only used as part of another schema.
Fields
image: Option<String>Optional. Container image to use.
java_jars: Option<Vec<String>>Optional. A list of Java JARS to add to the classpath. Valid input includes Cloud Storage URIs to Jar binaries. For example, gs://bucket-name/my/path/to/file.jar
properties: Option<HashMap<String, String>>Optional. Override to common configuration of open source components installed on the Dataproc cluster. The properties to set on daemon config files. Property keys are specified in prefix:property format, for example core:hadoop.tmp.dir. For more information, see Cluster properties (https://cloud.google.com/dataproc/docs/concepts/cluster-properties).
python_packages: Option<Vec<String>>Optional. A list of python packages to be installed. Valid formats include Cloud Storage URI to a PIP installable library. For example, gs://bucket-name/my/path/to/lib.tar.gz