pub struct GoogleCloudDataplexV1TaskTriggerSpec {
pub disabled: Option<bool>,
pub max_retries: Option<i32>,
pub schedule: Option<String>,
pub start_time: Option<DateTime<Utc>>,
pub type_: Option<String>,
}Expand description
Task scheduling and trigger settings.
This type is not used in any activity, and only used as part of another schema.
Fields
disabled: Option<bool>Optional. Prevent the task from executing. This does not cancel already running tasks. It is intended to temporarily disable RECURRING tasks.
max_retries: Option<i32>Optional. Number of retry attempts before aborting. Set to zero to never attempt to retry a failed task.
schedule: Option<String>Optional. Cron schedule (https://en.wikipedia.org/wiki/Cron) for running tasks periodically. To explicitly set a timezone to the cron tab, apply a prefix in the cron tab: “CRON_TZ=${IANA_TIME_ZONE}” or “TZ=${IANA_TIME_ZONE}”. The ${IANA_TIME_ZONE} may only be a valid string from IANA time zone database. For example, CRON_TZ=America/New_York 1 * * * *, or TZ=America/New_York 1 * * * *. This field is required for RECURRING tasks.
start_time: Option<DateTime<Utc>>Optional. The first run of the task will be after this time. If not specified, the task will run shortly after being submitted if ON_DEMAND and based on the schedule if RECURRING.
type_: Option<String>Required. Immutable. Trigger type of the user-specified Task.