pub struct GoogleCloudDataplexV1TriggerOneTime {
pub ttl_after_scan_completion: Option<Duration>,
}Expand description
The scan runs once using create API.
This type is not used in any activity, and only used as part of another schema.
Fields
ttl_after_scan_completion: Option<Duration>Optional. Time to live for OneTime scans. default value is 24 hours, minimum value is 0 seconds, and maximum value is 365 days. The time is calculated from the data scan job completion time. If value is set as 0 seconds, the scan will be immediately deleted upon job completion, regardless of whether the job succeeded or failed.