pub struct GoogleCloudDataplexV1DataDiscoverySpecStorageConfig {
pub csv_options: Option<GoogleCloudDataplexV1DataDiscoverySpecStorageConfigCsvOptions>,
pub exclude_patterns: Option<Vec<String>>,
pub include_patterns: Option<Vec<String>>,
pub json_options: Option<GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions>,
}Expand description
Configurations related to Cloud Storage as the data source.
This type is not used in any activity, and only used as part of another schema.
Fields
csv_options: Option<GoogleCloudDataplexV1DataDiscoverySpecStorageConfigCsvOptions>Optional. Configuration for CSV data.
exclude_patterns: Option<Vec<String>>Optional. Defines the data to exclude during discovery. Provide a list of patterns that identify the data to exclude. For Cloud Storage bucket assets, these patterns are interpreted as glob patterns used to match object names. For BigQuery dataset assets, these patterns are interpreted as patterns to match table names.
include_patterns: Option<Vec<String>>Optional. Defines the data to include during discovery when only a subset of the data should be considered. Provide a list of patterns that identify the data to include. For Cloud Storage bucket assets, these patterns are interpreted as glob patterns used to match object names. For BigQuery dataset assets, these patterns are interpreted as patterns to match table names.
json_options: Option<GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions>Optional. Configuration for JSON data.