pub struct GoogleCloudDataplexV1EntryLinkEntryReference {
pub name: Option<String>,
pub path: Option<String>,
pub type_: Option<String>,
}Expand description
Reference to the Entry that is linked through the Entry Link.
This type is not used in any activity, and only used as part of another schema.
Fields
name: Option<String>Required. Immutable. The relative resource name of the referenced Entry, of the form: projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}
path: Option<String>Immutable. The path in the Entry that is referenced in the Entry Link. Empty path denotes that the Entry itself is referenced in the Entry Link.
type_: Option<String>Required. Immutable. The reference type of the Entry.