pub struct GoogleCloudDataplexV1EntrySource {
pub ancestors: Option<Vec<GoogleCloudDataplexV1EntrySourceAncestor>>,
pub create_time: Option<DateTime<Utc>>,
pub description: Option<String>,
pub display_name: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub location: Option<String>,
pub platform: Option<String>,
pub resource: Option<String>,
pub system: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
Information related to the source system of the data resource that is represented by the entry.
This type is not used in any activity, and only used as part of another schema.
Fields
ancestors: Option<Vec<GoogleCloudDataplexV1EntrySourceAncestor>>Immutable. The entries representing the ancestors of the data resource in the source system.
create_time: Option<DateTime<Utc>>The time when the resource was created in the source system.
description: Option<String>A description of the data resource. Maximum length is 2,000 characters.
display_name: Option<String>A user-friendly display name. Maximum length is 500 characters.
labels: Option<HashMap<String, String>>User-defined labels. The maximum size of keys and values is 128 characters each.
location: Option<String>Output only. Location of the resource in the source system. You can search the entry by this location. By default, this should match the location of the entry group containing this entry. A different value allows capturing the source location for data external to Google Cloud.
platform: Option<String>The platform containing the source system. Maximum length is 64 characters.
resource: Option<String>The name of the resource in the source system. Maximum length is 4,000 characters.
system: Option<String>The name of the source system. Maximum length is 64 characters.
update_time: Option<DateTime<Utc>>The time when the resource was last updated in the source system. If the entry exists in the system and its EntrySource has update_time populated, further updates to the EntrySource of the entry must provide incremental updates to its update_time.