pub struct GoogleCloudDataplexV1MetadataJobExportJobSpec {
pub output_path: Option<String>,
pub scope: Option<GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope>,
}Expand description
Job specification for a metadata export job.
This type is not used in any activity, and only used as part of another schema.
Fields
output_path: Option<String>Required. The root path of the Cloud Storage bucket to export the metadata to, in the format gs://{bucket}/. You can optionally specify a custom prefix after the bucket name, in the format gs://{bucket}/{prefix}/. The maximum length of the custom prefix is 128 characters. Dataplex Universal Catalog constructs the object path for the exported files by using the bucket name and prefix that you provide, followed by a system-generated path.The bucket must be in the same VPC Service Controls perimeter as the job.
scope: Option<GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope>Required. The scope of the export job.